@@ -73,15 +73,16 @@ class BasicTestCase(unittest.TestCase):
         results = RESULT_TAB.split('\n')
         line_no = 0
         for line in self.crontab.lines:
-            self.assertEqual(line, results[line_no])
+            self.assertEqual(str(line), results[line_no])
             line_no += 1
 
     def test_02_access(self):
         """All Entries Are Accessable"""
         line_no = 0
-        for cron in self.crontab:
-            self.assertEqual(str(cron.command), COMMANDS[line_no])
+        for job in self.crontab:
+            self.assertEqual(str(job.command), COMMANDS[line_no])
             line_no += 1
+        self.assertEqual(line_no, 6)
 
     def test_03_blank(self):
         """Render Blank"""
@@ -153,9 +154,9 @@ class BasicTestCase(unittest.TestCase):
 
     def test_11_disabled(self):
         """Disabled Job"""
-        jobs = self.crontab.find_command('firstcommand')
+        jobs = list(self.crontab.find_command('firstcommand'))
         self.assertTrue(jobs[0].enabled)
-        jobs = self.crontab.find_command('disabled')
+        jobs = list(self.crontab.find_command('disabled'))
         self.assertFalse(jobs[0].enabled)
 
     def test_12_disable(self):
@@ -177,10 +178,10 @@ class BasicTestCase(unittest.TestCase):
         cron = '# start of tab'
         for i in range(10):
             crontab = CronTab(tab=cron)
-            job = crontab.new(command='multi')
+            job = list(crontab.new(command='multi'))
             cron = unicode(crontab)
             crontab = CronTab(tab=cron)
-            crontab.find_command('multi')[0].delete()
+            list(crontab.find_command('multi'))[0].delete()
             cron = unicode(crontab)
         self.assertEqual(unicode(crontab), '# start of tab\n')
 
@@ -202,28 +203,54 @@ class BasicTestCase(unittest.TestCase):
         job.month.on('>')
         self.assertEqual(unicode(job), '59 23 31 12 * max')
 
-    def test_24_specials(self):
-        """Specials Conversion"""
+    def test_24_special_r(self):
+        """Read Specials"""
+        tab = CronTab(tabfile='data/specials_enc.tab')
+        self.assertEqual(tab.render(), """@hourly hourly\n@daily daily\n@daily midnight\n@weekly weekly\n@reboot reboot\n""")
+        self.assertEqual(len(list(tab)), 5)
+
+    def test_24_special_d(self):
+        """Removal All Specials"""
+        tab = CronTab(tabfile='data/specials.tab')
+        tab.remove_all()
+        self.assertEqual(len(list(tab)), 0)
+
+    def test_24_special_w(self):
+        """Write Specials"""
         tab = CronTab(tabfile='data/specials.tab')
         self.assertEqual(tab.render(), """@hourly hourly\n@daily daily\n@weekly weekly\n""")
+        self.assertEqual(len(list(tab)), 3)
 
     def test_25_setall(self):
         """Set all values at once"""
         job = self.crontab.new(command='all')
         job.setall(1, '*/2', '2-4', '>', 'SUN')
         self.assertEqual(unicode(job), '1 */2 2-4 12 SUN all')
-        job.setall()
-        self.assertEqual(unicode(job), '* * * * * all')
+        job.setall('*/2')
+        self.assertEqual(unicode(job), '*/2 * * * * all')
         job.setall('1 */2 2-4 12 SUN')
         self.assertEqual(unicode(job), '1 */2 2-4 12 SUN all')
+        job.setall(['*'])
+        self.assertEqual(unicode(job), '* * * * * all')
 
-    def test_26_commands(self):
+    def test_26_setall_obj(self):
+        """Copy all values"""
+        job = self.crontab.new(command='all')
+        job2 = self.crontab.new(command='ignore')
+        job2.setall("1 */2 2-4 12 SUN")
+        job.setall(job2)
+        self.assertEqual(unicode(job), '1 */2 2-4 12 SUN all')
+        job2.setall("2 */3 4-8 10 MON")
+        job.setall(job2.slices)
+        self.assertEqual(unicode(job), '2 */3 4-8 10 MON all')
+
+    def test_27_commands(self):
         """Get all commands"""
         self.assertEqual(list(self.crontab.commands), 
                          [u'firstcommand', u'range', u'byweek',
                           u'disabled', u'spaced', u'rebooted'])
 
-    def test_27_comments(self):
+    def test_28_comments(self):
         """Get all comments"""
         self.assertEqual(list(self.crontab.comments),
                          ['Comment One', 'Comment  Two', 're-id'])
